@@ -38,7 +38,7 @@ class ApiEndpoint(object):
         fails = 0
         while fails < 2:
             self.rsp = requests.request(method, uri, data=data, headers=self.header, params=params)
-            logger.info('TRADEGECKO API REQUEST: %s %s \nDATA="%s" \nRESPONSE="%s" \nSTATUS_CODE: %s' % (method, uri, data, self.rsp.content, self.rsp.status_code))
+            logger.info('TRADEGECKO API REQUEST: %s %s \nDATA="%s" \nPARAMS="%s" \nRESPONSE="%s" \nSTATUS_CODE: %s' % (method, uri, data, params, self.rsp.content, self.rsp.status_code))
             if self.rsp.status_code == 429:
                 retry_after = int(self.rsp.headers.get('retry-after', 10))
                 time.sleep(retry_after)
